=========
ChangeLog
=========


v0.1.2
======

* Added asynchronous delivery of ``deferred`` templates
* Added direct serving of packaged templates via `mount-path` URL


v0.1.1
======

* First public release
